==> coastal_dynamics-0.0.6.tar.gz: coastal_dynamics-0.0.6/README.md <==
![](https://github.com/FlorisCalkoen/CoastalCodebook/blob/main/coastalcodebook/imgs/waves_angola.jpeg)
# Coastal Dynamics Open Codebook

Welcome to the [Coastal Dynamics Open
Codebook](https://floriscalkoen.github.io/CoastalCodebook/intro.html)! This project contains
interactive exercises that
cover material of the [Coastal Dynamics Open
Textbook](https://textbooks.open.tudelft.nl/textbooks/catalog/book/37) as well as a
[Python package](https://pypi.org/project/coastal-dynamics/), that is designed for
creating interactive questions, complete with a simple grading mechanism.

For more information regarding the course, installation and usage we refer the interested
reader to our [Jupyterbook](https://floriscalkoen.github.io/CoastalCodebook/intro.html),
that is available online!

## Usage

Detailed instructions for both the notebooks and the package are provided in our
Jupyterbook [online](https://floriscalkoen.github.io/CoastalCodebook/intro.html).

### Interactive teaching material

Instructions for running the tutorial notebooks are available
[here](https://floriscalkoen.github.io/CoastalCodebook/usage/installation.html).

### Package installation

Install the Python package using pip:

```bash
pip install coastal-dynamics
```



## Questions

If you have a question about the installation process or notebooks, feel free to open an
issue in the [GitHub repository](https://github.com/FlorisCalkoen/CoastalCodebook). If
that's your first time, have a look at [these
instructions](https://docs.github.com/en/issues/tracking-your-work-with-issues/creating-an-issue).
We choose to use the GitHub issue-tracker because your fellow students probably have
similar problems. We will probably not troubleshoot the tutorial notebooks by email!

## Contributors

We welcome and recognize all contributions. You can see a list of current contributors in
the [contributors
tab](https://github.com/floriscalkoen/coastalcodebook/graphs/contributors).

## Credits

This project is fully created open source software! Many thanks to [NUMFocus](https://numfocus.org) for
supporting and maintaining all these open source initiatives. We used [cookiecutter-jupyter-book
template](https://github.com/executablebooks/cookiecutter-jupyter-book) as our template
for the book structure.

==> coastal_dynamics-0.0.7.tar.gz: coastal_dynamics-0.0.7/README.md <==
![](https://github.com/FlorisCalkoen/CoastalCodebook/blob/main/coastalcodebook/imgs/waves_angola.jpeg)
# Coastal Dynamics Open Codebook

Welcome to the [Coastal Dynamics Open
Codebook](https://floriscalkoen.github.io/CoastalCodebook/intro.html)! This project contains
interactive exercises that
cover material of the [Coastal Dynamics Open
Textbook](https://textbooks.open.tudelft.nl/textbooks/catalog/book/37) as well as a
[Python package](https://pypi.org/project/coastal-dynamics/), that is designed for
creating interactive questions, complete with a simple grading mechanism.

For more information regarding the course, installation and usage we refer the interested
reader to our [Jupyterbook](https://floriscalkoen.github.io/CoastalCodebook/intro.html),
that is available online!

## Usage

Detailed instructions for both the notebooks and the package are provided in our
Jupyterbook [online](https://floriscalkoen.github.io/CoastalCodebook/intro.html).

### Interactive teaching material

Instructions for running the tutorial notebooks are available
[here](https://floriscalkoen.github.io/CoastalCodebook/usage/installation.html).

### Package installation

Install the Python package using pip:

```bash
pip install coastal-dynamics
```
### Architecture

#### Components
![architecture](https://github.com/FlorisCalkoen/CoastalCodebook/assets/44444001/47942d0d-e1aa-406d-9242-613333490427)


#### User usage 
![image](https://github.com/FlorisCalkoen/CoastalCodebook/assets/44444001/40a5112d-e830-42cf-9448-63c6d37fb147)


## Questions

If you have a question about the installation process or notebooks, feel free to open an
issue in the [GitHub repository](https://github.com/FlorisCalkoen/CoastalCodebook). If
that's your first time, have a look at [these
instructions](https://docs.github.com/en/issues/tracking-your-work-with-issues/creating-an-issue).
We choose to use the GitHub issue-tracker because your fellow students probably have
similar problems. We will probably not troubleshoot the tutorial notebooks by email!

## Contributors

We welcome and recognize all contributions. You can see a list of current contributors in
the [contributors
tab](https://github.com/floriscalkoen/coastalcodebook/graphs/contributors).

## Credits

This project is created by using open source software only! Many thanks to [NUMFocus](https://numfocus.org) for
supporting and maintaining all these open source initiatives. We used [cookiecutter-jupyter-book
template](https://github.com/executablebooks/cookiecutter-jupyter-book) as our template
for the book structure.
